﻿using System;
using System.Windows;
using System.Windows.Data;
using Infragistics.Windows.Reporting;
using System.Diagnostics;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            XmlDataProvider source = this.TryFindResource("MovieData") as XmlDataProvider;
            source.Source = new Uri(System.IO.Path.Combine(System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location), "datasources/Movies.xml"));
            source.XPath = "NewDataSet/TopMovies";
        }

        private void btnGenPreview_Click(object sender, RoutedEventArgs e)
        {
            // Create report and add visual to print
            Report reportObj = new Report();

            // Create section with chart
            EmbeddedVisualReportSection section = new EmbeddedVisualReportSection(xamDataGrid1);
            reportObj.Sections.Add(section);

            try
            {
                // Put report to preview control
                xamReportPreview1.GeneratePreview(reportObj, false, true);

                tabPreview.IsSelected = true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error generating Preview");
            }
        }

        private void btnExport_Click(object sender, RoutedEventArgs e)
        {
            extractToExcel();
        }

        private void extractToExcel()
        {
            string path = getExportPath();

            Infragistics.Windows.DataPresenter.ExcelExporter.DataPresenterExcelExporter exporter =
                new Infragistics.Windows.DataPresenter.ExcelExporter.DataPresenterExcelExporter();
            Infragistics.Windows.DataPresenter.ExcelExporter.ExportOptions exportOptions =
                new Infragistics.Windows.DataPresenter.ExcelExporter.ExportOptions();

            exportOptions.FileLimitBehaviour = Infragistics.Windows.DataPresenter.ExcelExporter.FileLimitBehaviour.TruncateData;
            exportOptions.ChildRecordCollectionSpacing = Infragistics.Windows.DataPresenter.ExcelExporter.ChildRecordCollectionSpacing.SingleRow;

            exporter.Export(xamDataGrid1, path, Infragistics.Documents.Excel.WorkbookFormat.Excel2007, exportOptions);

            ProcessStartInfo psi = new ProcessStartInfo(path);
            psi.UseShellExecute = true;
            Process.Start(psi);
        }

        private string getExportPath()
        {
            string path = System.Environment.GetEnvironmentVariable("TEMP") + @"\InfraTest";
            string outPiece = string.Empty;
            int cnt = 0;
            while (true)
            {
                if (System.IO.File.Exists(path + outPiece + ".xlsx"))
                {
                    outPiece = "(" + cnt.ToString() + ")";
                    cnt++;
                }
                else
                    break;
            }

            return path + outPiece + ".xlsx";
        }

    }
}
